/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2010 Bull S.A.S.
 * Copyright (C) 2010 EMN
 * Copyright (C) 2010 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Author(s):
 * 		Mahmoud Ben Hassine (IRISA)
 *  
 */
package org.ow2.wildcat.examples.bank;

import java.util.Vector;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;
import org.ow2.wildcat.examples.bank.util.BankDataBase;
import org.ow2.wildcat.examples.bank.util.TxDetails;

import com.espertech.esper.client.EventBean;
import com.espertech.esper.client.UpdateListener;


/**
 * Wildcat context of the bank resources
 * @author Mahmoud Ben Hassine
 *
 */
public class BankWContext {

	public BankWContext(){
	}
	
	public void init() {
		
		/*
		 * create a context with default options
		 */
		Context	ctx = ContextFactory.getDefaultFactory().createContext();
		
		/*
		 * get customers from the database
		 */
        Vector<Customer> customers = BankDataBase.getInstance().getCustomers();
        
        try {
        	/*
        	 * create bank resource hierarchy and attach/connect sensors to attributes
        	 */
        	for (int i = 1; i < 7; i++) 
        		ctx.attachAttribute("self://bank/accounts#a" + i, customers.get(i-1).getAccount().getSensor());

        	/*
        	 * register a simple listener to log transactions to the console
        	 */
	        ctx.registerListeners("select value from WAttributeEvent", new UpdateListener() {
	            public void update(final EventBean[] newEvents, final EventBean[] oldEvents) {
	            	/*
	            	 * get encapsulated transaction details sent by the sensor
	            	 */
	                TxDetails transaction = (TxDetails) newEvents[0].get("value");
	                System.out.println(transaction);    
	            }
	        });
	        
		} catch (ContextException e) {
			e.printStackTrace();
		}
		      
    }
}
