/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2010 Bull S.A.S.
 * Copyright (C) 2010 EMN
 * Copyright (C) 2010 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Author(s):
 * 		Mahmoud Ben Hassine (IRISA)
 *  
 */
package org.ow2.wildcat.examples.pull;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;

/**
 * Usage example of PULL mode
 */
public class PULLModeExample {
	
	public static void main(final String[] args) {
		/*
		 * Creating a context through the ContextFactory
		 */
		Context ctx = ContextFactory.getDefaultFactory().createContext("TechnicalResources");
		/*
		 * Getting the context name
		 */
		System.out.println("Context name = " + ctx.getName());
		try {
			/*
			 * Creating some resources
			 */
			ctx.createResource("self://computers/pc1");
			ctx.createResource("self://computers/pc2");
			ctx.createResource("self://printers/ColorPrinter");
			ctx.createResource("self://printers/BWPrinter");
			/*
			 * Creating and initializing attributes
			 */
			ctx.createAttribute("self://computers/pc1#name", "pc1");
			ctx.createAttribute("self://computers/pc1#status", "ON");
			ctx.createAttribute("self://computers/pc2#name", "pc2");
			ctx.createAttribute("self://computers/pc2#status", "OFF");
			ctx.createAttribute("self://printers/ColorPrinter#name", "colorprinter");
			ctx.createAttribute("self://printers/ColorPrinter#status","Standby");
			ctx.createAttribute("self://printers/BWPrinter#name", "bwprinter");
			ctx.createAttribute("self://printers/BWPrinter#status", "Standby");
			/*
			 * Listing all printers
			 */
			System.out.println("Printers = " + ctx.list("self://printers"));
			/*
			 * Getting pc2 status attribute
			 */
			System.out.println("pc2 status is : "
					+ ctx.getValue("self://computers/pc2#status"));
			/*
			 * Setting pc1 status attribute to OFF
			 */
			ctx.setValue("self://computers/pc1#status", "OFF");
			System.out.println("pc1 status is : "
					+ ctx.getValue("self://computers/pc1#status"));
			/*
			 * Creating a symbolic link to the Black and White printer
			 */
			ctx.createSymlink("self://bwp", "self://printers/BWPrinter");
			/*
			 * Getting BWPrinter status attribute using the symbolic link
			 */
			System.out.println("BWPrinter status is : "
					+ ctx.getValue("self://bwp#status"));
		} catch (ContextException e) {
			e.printStackTrace();
		}
	}// end main
}// end PULLModeExample