/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2010 Bull S.A.S.
 * Copyright (C) 2010 EMN
 * Copyright (C) 2010 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Author(s):
 * 		Mahmoud Ben Hassine (IRISA)
 *  
 */
package org.ow2.wildcat.examples.push;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;
import org.ow2.wildcat.Query;
import org.ow2.wildcat.WAction;
import org.ow2.wildcat.hierarchy.attribute.QueryAttribute;
import org.ow2.wildcat.sensors.JavaRuntimeSensor;
import java.util.concurrent.TimeUnit;

/**
 * Usage example of PUSH mode
 */
public class PUSHModeExample {

	public static void main(String[] args) {
		/*
		 * Creating a context through the ContextFactory
		 */
		Context ctx = ContextFactory.getDefaultFactory().createContext();
		
		try {
			/*
			 * Creating and attaching a JavaRuntuime Sensor to a specific attribute
			 */
			ctx.attachAttribute("self://jvm#javaRuntime", new JavaRuntimeSensor());
			
			/*
			 * Creating a periodic attribute poller for the "self://jvm#javaRuntime"
			 * attribute
			 */
			ctx.createPeriodicAttributePoller("self://jvm#javaRuntime", 1 , TimeUnit.SECONDS);
			
			/*
			 * Creating a query attribute holding the (jvm) used memory
			 */
			QueryAttribute usedMemory = new QueryAttribute("select ((cast(value('total-memory')?,long))-(cast(value('free-memory')?,long)))" +
			"as usedMemory from WAttributeEvent(source = 'self://jvm#javaRuntime')");
			
			/*
			 * Attaching the query attribute "usedMemory" to the hierarchy
			 */
			ctx.attachAttribute("self://jvm#usedMemory", usedMemory);
			
			/*
			 *Creating a query to select the maximum of (jvm) used memory for the last *5 seconds
			 */
			Query query = ctx.createQuery("select max(cast(value('usedMemory')?,long))" +
			" as MaxUsedMemory from WAttributeEvent(source = 'self://jvm#usedMemory').win:time(5 sec)");
			
			/*
			 * Registering a simple action to the query
			 */
			ctx.registerActions(query, new WAction() {
				@Override
				public void onEvent() {
					System.out.println("Maximum of used memory for the last 5 seconds = " + getListener().getNewEvents()[0].get("MaxUsedMemory"));
				}
			});
			
		} catch (ContextException e) {
				e.printStackTrace();
		}

	}// end main
}// end PUSHModeExample