/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 * --------------------------------------------------------------------------
 * $Id: CPUInfoSensor.java 350 2008-11-10 09:41:14Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.sensors;

import java.text.ParseException;
import java.util.HashMap;
import java.util.Map;

/**
 * CPU Info sensor. Sample informations from "/proc/cpuinfo".
 */
public final class CPUInfoSensor extends TextFileSensor implements Sensor {

    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = -4876635381240076523L;

    /**
     * Default constructor
     */
    public CPUInfoSensor() {
        super("/proc/cpuinfo");
    }

    /*
     * (non-Javadoc)
     *
     * @see org.ow2.wildcat.sensors.TextFileSensor#getValues(java.lang.String[])
     */
    @Override
    protected Map<String, Object> getValues(final String[] lines) {
        Map<String, Object> samples = new HashMap<String, Object>();
        for (int i = 0; i < LINE_FORMATS.length; i++) {
            String name = LINE_FORMATS[i].getProperty();
            Object value = null;
            try {
                value = ((Object[]) LINE_FORMATS[i].getFormat().parseObject(
                        lines[i]))[0];
            } catch (ParseException e) {
                // ignore and continue
            }
            if (value instanceof Number) {
                samples.put(name, value);
            } else if (value instanceof String) {
                samples.put(name, value);
            } else if (value instanceof Boolean) {
                samples.put(name, value);
            } else {
                throw new RuntimeException("Should not happen.");
            }
        }
        return samples;
    }

    private static final LineFormat[] LINE_FORMATS = new LineFormat[] {
        new LineFormat("processor", "processor\t: {0,number,integer}"),
        new LineFormat("vendor_id", "vendor_id\t: {0}"),
        new LineFormat("cpu_family", "cpu family\t: {0,number,integer}"),
        new LineFormat("model", "model\t\t: {0,number,integer}"),
        new LineFormat("model_name", "model name\t: {0}"),
        new LineFormat("stepping", "stepping\t: {0,number,integer}"),
        new LineFormat("speed", "cpu MHz\t\t: {0,number}"),
        new LineFormat("cache", "cache size\t: {0,number,integer} KB") };
}
